@@ -151,11 +151,20 @@ renv_scope_rtools <- function(.envir = NULL) {
 
 # nocov start
 renv_scope_install <- function(.envir = NULL) {
+
   .envir <- .envir %||% parent.frame()
 
-  # currently only required on macOS
-  if (!renv_platform_macos())
-    return(FALSE)
+  if (renv_platform_macos())
+    renv_scope_install_macos(.envir)
+
+  if (renv_platform_wsl())
+    renv_scope_install_wsl(.envir)
+
+}
+
+renv_scope_install_macos <- function(.envir = NULL) {
+
+  .envir <- .envir %||% parent.frame()
 
   # get the current compiler
   args <- c("CMD", "config", "CC")
@@ -229,4 +238,15 @@ renv_scope_install <- function(.envir = NULL) {
   TRUE
 
 }
+
+renv_scope_install_wsl <- function(.envir = NULL) {
+  .envir <- .envir %||% parent.frame()
+  renv_scope_envvars(R_INSTALL_STAGED = "FALSE")
+}
 # nocov end
+
+renv_scope_restore <- function(..., .envir = NULL) {
+  .envir <- .envir %||% parent.frame()
+  state <- renv_restore_begin(...)
+  defer(renv_restore_end(state), envir = .envir)
+}
